package geniusweb.references;

import java.util.HashMap;

/**
 * init parameters for a party. Object must be either a HashMap, List, String or
 * Number. Other objects may not deserialize properly. We never use blanket
 * Object deserializers (enableDefaultTyping) because of security reasons.
 *
 */
public class Parameters extends HashMap<String, Object> {

	/**
	 * Getter with type-check
	 * 
	 * @param <T>       the expected type
	 * @param paramname the parameter name that must be in the map
	 * @param classType the expected value type for this parameter
	 * @return object of requested type.
	 * @throws IllegalArgumentException if the object is not available.
	 */
	@SuppressWarnings("unchecked")
	public <T> T get(String paramname, Class<T> classType) {
		if (!containsKey(paramname)
				|| !(get(paramname).getClass().isInstance(classType)))
			throw new IllegalArgumentException(" Missing contain a parameter "
					+ paramname + " with a " + classType.getName() + " value");
		return (T) get(paramname);
	}
}
